@@ -3,7 +3,6 @@
 from __future__ import absolute_import
 
 import logging
-import collections
 import sys
 
 from colorlog.escape_codes import escape_codes, parse_colors
@@ -30,27 +29,18 @@ default_formats = {
 
 class ColoredRecord(object):
     """
-    Wraps a LogRecord and attempts to parse missing keys as escape codes.
+    Wraps a LogRecord, adding named escape codes to the internal dict.
 
-    When the record is formatted, the logging library uses ``record.__dict__``
-    directly - so this class replaced the dict with a ``defaultdict`` that
-    checks if a missing key is an escape code.
+    The internal dict is used when formatting the message (by the PercentStyle,
+    StrFormatStyle, and StringTemplateStyle classes).
     """
 
-    class __dict(collections.defaultdict):
-        def __missing__(self, name):
-            try:
-                return parse_colors(name)
-            except Exception:
-                raise KeyError("{} is not a valid record attribute "
-                               "or color sequence".format(name))
-
     def __init__(self, record):
-        # Replace the internal dict with one that can handle missing keys
-        self.__dict__ = self.__dict()
+        """Add attributes from the escape_codes dict and the record."""
+        self.__dict__.update(escape_codes)
         self.__dict__.update(record.__dict__)
 
-        # Keep a refrence to the original refrence so ``__getattr__`` can
+        # Keep a reference to the original record so ``__getattr__`` can
         # access functions that are not in ``__dict__``
         self.__record = record
 
@@ -206,8 +196,8 @@ class TTYColoredFormatter(ColoredFormatter):
     """
 
     def __init__(self, *args, **kwargs):
-        """Overwrites the `reset` argument to False if stream is not a TTY."""
-        self.stream = kwargs.pop('stream', sys.stdout)
+        """Overwrite the `reset` argument to False if stream is not a TTY."""
+        self.stream = kwargs.pop('stream')
 
         # Both `reset` and `isatty` must be true to insert reset codes.
         kwargs['reset'] = kwargs.get('reset', True) and self.stream.isatty()
